@@ -7,73 +7,62 @@ pub enum Error {
     /// Application can authenticate against GCP using:
     ///
     /// - Default service account - available inside GCP platform using GCP Instance Metadata server
-    /// - Service account file - provided using `GOOGLE_APPLICATION_CREDENTIALS` with path
     /// - GCloud authorized user - retrieved using `gcloud auth` command
     ///
     /// All authentication methods have been tested and none succeeded.
     /// Service account file can be downloaded from GCP in json format.
     #[error("No available authentication method was discovered")]
-    NoAuthMethod(Box<Error>, Box<Error>, Box<Error>, Box<Error>),
+    NoAuthMethod(Box<Error>, Box<Error>, Box<Error>),
 
     /// Error in underlying RustTLS library.
     /// Might signal problem with establishing secure connection using trusted certificates
     #[error("TLS error")]
-    TLSError(rustls::Error),
+    TlsError(#[source] rustls::Error),
 
     /// Error when establishing connection to OAuth server
     #[error("Could not establish connection with OAuth server")]
-    OAuthConnectionError(hyper::Error),
+    OAuthConnectionError(#[source] hyper::Error),
 
-    /// Error when parsing response from OAuth server
-    #[error("Could not parse OAuth server response")]
-    OAuthParsingError(serde_json::error::Error),
-
-    /// Variable `GOOGLE_APPLICATION_CREDENTIALS` could not be found in the current environment
+    /// Wrong path to custom service account credentials provided
     ///
-    /// GOOGLE_APPLICATION_CREDENTIALS is used for providing path to json file with applications credentials.
-    /// File can be downloaded in GCP Console when creating service account.
-    #[error("Path to custom auth credentials was not provided in `GOOGLE_APPLICATION_CREDENTIALS` env variable")]
-    ApplicationProfileMissing,
+    /// By default, the custom service account credentials are parsed from the path pointed to by the
+    /// `GOOGLE_APPLICATION_CREDENTIALS` environment variable.
+    #[error("Invalid path to custom service account")]
+    CustomServiceAccountPath(#[source] std::io::Error),
 
-    /// Wrong path to custom application profile credentials provided
+    /// Failed to parse the application credentials provided
     ///
-    /// Path has to be defined using `GOOGLE_APPLICATION_CREDENTIALS` environment variable
-    #[error("Environment variable `GOOGLE_APPLICATION_CREDENTIALS` contains invalid path to application profile file")]
-    ApplicationProfilePath(std::io::Error),
-
-    /// Wrong format of custom application profile
-    ///
-    /// Application profile is downloaded from GCP console and is stored in filesystem on the server.
-    /// Full path is passed to library by setting `GOOGLE_APPLICATION_CREDENTIALS` variable with path as a value.
+    /// By default, the custom service account credentials are parsed from the path pointed to by the
+    /// `GOOGLE_APPLICATION_CREDENTIALS` environment variable.
     #[error("Application profile provided in `GOOGLE_APPLICATION_CREDENTIALS` was not parsable")]
-    ApplicationProfileFormat(serde_json::error::Error),
+    CustomServiceAccountCredentials(#[source] serde_json::error::Error),
 
     /// Default user profile not found
     ///
     /// User can authenticate locally during development using `gcloud auth login` which results in creating
     /// `~/.config/gcloud/application_default_credentials.json` which couldn't be find on the machine
     #[error("User authentication profile not found")]
-    UserProfilePath(std::io::Error),
+    UserProfilePath(#[source] std::io::Error),
 
     /// Wrong format of user profile
     #[error("User profile was not parsable")]
-    UserProfileFormat(serde_json::error::Error),
+    UserProfileFormat(#[source] serde_json::error::Error),
 
     /// Could not connect to  server
     #[error("Could not establish connection with server")]
-    ConnectionError(hyper::Error),
+    ConnectionError(#[source] hyper::Error),
 
     /// Could not parse response from server
     #[error("Could not parse server response")]
-    ParsingError(serde_json::error::Error),
+    ParsingError(#[source] serde_json::error::Error),
 
     /// Could not connect to server
     #[error("Server unavailable: {0}")]
     ServerUnavailable(String),
 
-    /// Could not determine signer scheme
-    #[error("Couldn't choose signing scheme")]
-    SignerSchemeError,
+    /// Could not sign requested message
+    #[error("Could not sign")]
+    SignerFailed,
 
     /// Could not initialize signer
     #[error("Couldn't initialize signer")]
